@@ -1,4 +1,101 @@
-(function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
+/******/ (function(modules) { // webpackBootstrap
+/******/ 	// The module cache
+/******/ 	var installedModules = {};
+/******/
+/******/ 	// The require function
+/******/ 	function __webpack_require__(moduleId) {
+/******/
+/******/ 		// Check if module is in cache
+/******/ 		if(installedModules[moduleId]) {
+/******/ 			return installedModules[moduleId].exports;
+/******/ 		}
+/******/ 		// Create a new module (and put it into the cache)
+/******/ 		var module = installedModules[moduleId] = {
+/******/ 			i: moduleId,
+/******/ 			l: false,
+/******/ 			exports: {}
+/******/ 		};
+/******/
+/******/ 		// Execute the module function
+/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
+/******/
+/******/ 		// Flag the module as loaded
+/******/ 		module.l = true;
+/******/
+/******/ 		// Return the exports of the module
+/******/ 		return module.exports;
+/******/ 	}
+/******/
+/******/
+/******/ 	// expose the modules object (__webpack_modules__)
+/******/ 	__webpack_require__.m = modules;
+/******/
+/******/ 	// expose the module cache
+/******/ 	__webpack_require__.c = installedModules;
+/******/
+/******/ 	// define getter function for harmony exports
+/******/ 	__webpack_require__.d = function(exports, name, getter) {
+/******/ 		if(!__webpack_require__.o(exports, name)) {
+/******/ 			Object.defineProperty(exports, name, {
+/******/ 				configurable: false,
+/******/ 				enumerable: true,
+/******/ 				get: getter
+/******/ 			});
+/******/ 		}
+/******/ 	};
+/******/
+/******/ 	// getDefaultExport function for compatibility with non-harmony modules
+/******/ 	__webpack_require__.n = function(module) {
+/******/ 		var getter = module && module.__esModule ?
+/******/ 			function getDefault() { return module['default']; } :
+/******/ 			function getModuleExports() { return module; };
+/******/ 		__webpack_require__.d(getter, 'a', getter);
+/******/ 		return getter;
+/******/ 	};
+/******/
+/******/ 	// Object.prototype.hasOwnProperty.call
+/******/ 	__webpack_require__.o = function(object, property) { return Object.prototype.hasOwnProperty.call(object, property); };
+/******/
+/******/ 	// __webpack_public_path__
+/******/ 	__webpack_require__.p = "";
+/******/
+/******/ 	// Load entry module and return exports
+/******/ 	return __webpack_require__(__webpack_require__.s = 10);
+/******/ })
+/************************************************************************/
+/******/ ([
+/* 0 */,
+/* 1 */,
+/* 2 */,
+/* 3 */,
+/* 4 */,
+/* 5 */,
+/* 6 */,
+/* 7 */,
+/* 8 */,
+/* 9 */,
+/* 10 */
+/***/ (function(module, exports, __webpack_require__) {
+
+/*globals wp */
+
+var media = wp.media;
+
+media.controller.EditAttachmentMetadata = __webpack_require__( 11 );
+media.view.MediaFrame.Manage = __webpack_require__( 12 );
+media.view.Attachment.Details.TwoColumn = __webpack_require__( 13 );
+media.view.MediaFrame.Manage.Router = __webpack_require__( 14 );
+media.view.EditImage.Details = __webpack_require__( 15 );
+media.view.MediaFrame.EditAttachments = __webpack_require__( 16 );
+media.view.SelectModeToggleButton = __webpack_require__( 17 );
+media.view.DeleteSelectedButton = __webpack_require__( 18 );
+media.view.DeleteSelectedPermanentlyButton = __webpack_require__( 19 );
+
+
+/***/ }),
+/* 11 */
+/***/ (function(module, exports) {
+
 /*globals wp */
 
 /**
@@ -28,569 +125,11 @@ EditAttachmentMetadata = wp.media.controller.State.extend({
 
 module.exports = EditAttachmentMetadata;
 
-},{}],2:[function(require,module,exports){
-/*globals wp */
 
-var media = wp.media;
+/***/ }),
+/* 12 */
+/***/ (function(module, exports) {
 
-media.controller.EditAttachmentMetadata = require( './controllers/edit-attachment-metadata.js' );
-media.view.MediaFrame.Manage = require( './views/frame/manage.js' );
-media.view.Attachment.Details.TwoColumn = require( './views/attachment/details-two-column.js' );
-media.view.MediaFrame.Manage.Router = require( './routers/manage.js' );
-media.view.EditImage.Details = require( './views/edit-image-details.js' );
-media.view.MediaFrame.EditAttachments = require( './views/frame/edit-attachments.js' );
-media.view.SelectModeToggleButton = require( './views/button/select-mode-toggle.js' );
-media.view.DeleteSelectedButton = require( './views/button/delete-selected.js' );
-media.view.DeleteSelectedPermanentlyButton = require( './views/button/delete-selected-permanently.js' );
-
-},{"./controllers/edit-attachment-metadata.js":1,"./routers/manage.js":3,"./views/attachment/details-two-column.js":4,"./views/button/delete-selected-permanently.js":5,"./views/button/delete-selected.js":6,"./views/button/select-mode-toggle.js":7,"./views/edit-image-details.js":8,"./views/frame/edit-attachments.js":9,"./views/frame/manage.js":10}],3:[function(require,module,exports){
-/*globals wp, Backbone */
-
-/**
- * wp.media.view.MediaFrame.Manage.Router
- *
- * A router for handling the browser history and application state.
- *
- * @class
- * @augments Backbone.Router
- */
-var Router = Backbone.Router.extend({
-	routes: {
-		'upload.php?item=:slug':    'showItem',
-		'upload.php?search=:query': 'search'
-	},
-
-	// Map routes against the page URL
-	baseUrl: function( url ) {
-		return 'upload.php' + url;
-	},
-
-	// Respond to the search route by filling the search field and trigggering the input event
-	search: function( query ) {
-		jQuery( '#media-search-input' ).val( query ).trigger( 'input' );
-	},
-
-	// Show the modal with a specific item
-	showItem: function( query ) {
-		var media = wp.media,
-			library = media.frame.state().get('library'),
-			item;
-
-		// Trigger the media frame to open the correct item
-		item = library.findWhere( { id: parseInt( query, 10 ) } );
-		if ( item ) {
-			media.frame.trigger( 'edit:attachment', item );
-		} else {
-			item = media.attachment( query );
-			media.frame.listenTo( item, 'change', function( model ) {
-				media.frame.stopListening( item );
-				media.frame.trigger( 'edit:attachment', model );
-			} );
-			item.fetch();
-		}
-	}
-});
-
-module.exports = Router;
-
-},{}],4:[function(require,module,exports){
-/*globals wp */
-
-/**
- * wp.media.view.Attachment.Details.TwoColumn
- *
- * A similar view to media.view.Attachment.Details
- * for use in the Edit Attachment modal.
- *
- * @class
- * @augments wp.media.view.Attachment.Details
- * @augments wp.media.view.Attachment
- * @augments wp.media.View
- * @augments wp.Backbone.View
- * @augments Backbone.View
- */
-var Details = wp.media.view.Attachment.Details,
-	TwoColumn;
-
-TwoColumn = Details.extend({
-	template: wp.template( 'attachment-details-two-column' ),
-
-	editAttachment: function( event ) {
-		event.preventDefault();
-		this.controller.content.mode( 'edit-image' );
-	},
-
-	/**
-	 * Noop this from parent class, doesn't apply here.
-	 */
-	toggleSelectionHandler: function() {},
-
-	render: function() {
-		Details.prototype.render.apply( this, arguments );
-
-		wp.media.mixin.removeAllPlayers();
-		this.$( 'audio, video' ).each( function (i, elem) {
-			var el = wp.media.view.MediaDetails.prepareSrc( elem );
-			new window.MediaElementPlayer( el, wp.media.mixin.mejsSettings );
-		} );
-	}
-});
-
-module.exports = TwoColumn;
-
-},{}],5:[function(require,module,exports){
-/*globals wp */
-
-/**
- * wp.media.view.DeleteSelectedPermanentlyButton
- *
- * When MEDIA_TRASH is true, a button that handles bulk Delete Permanently logic
- *
- * @class
- * @augments wp.media.view.DeleteSelectedButton
- * @augments wp.media.view.Button
- * @augments wp.media.View
- * @augments wp.Backbone.View
- * @augments Backbone.View
- */
-var Button = wp.media.view.Button,
-	DeleteSelected = wp.media.view.DeleteSelectedButton,
-	DeleteSelectedPermanently;
-
-DeleteSelectedPermanently = DeleteSelected.extend({
-	initialize: function() {
-		DeleteSelected.prototype.initialize.apply( this, arguments );
-		this.listenTo( this.controller, 'select:activate', this.selectActivate );
-		this.listenTo( this.controller, 'select:deactivate', this.selectDeactivate );
-	},
-
-	filterChange: function( model ) {
-		this.canShow = ( 'trash' === model.get( 'status' ) );
-	},
-
-	selectActivate: function() {
-		this.toggleDisabled();
-		this.$el.toggleClass( 'hidden', ! this.canShow );
-	},
-
-	selectDeactivate: function() {
-		this.toggleDisabled();
-		this.$el.addClass( 'hidden' );
-	},
-
-	render: function() {
-		Button.prototype.render.apply( this, arguments );
-		this.selectActivate();
-		return this;
-	}
-});
-
-module.exports = DeleteSelectedPermanently;
-
-},{}],6:[function(require,module,exports){
-/*globals wp */
-
-/**
- * wp.media.view.DeleteSelectedButton
- *
- * A button that handles bulk Delete/Trash logic
- *
- * @class
- * @augments wp.media.view.Button
- * @augments wp.media.View
- * @augments wp.Backbone.View
- * @augments Backbone.View
- */
-var Button = wp.media.view.Button,
-	l10n = wp.media.view.l10n,
-	DeleteSelected;
-
-DeleteSelected = Button.extend({
-	initialize: function() {
-		Button.prototype.initialize.apply( this, arguments );
-		if ( this.options.filters ) {
-			this.listenTo( this.options.filters.model, 'change', this.filterChange );
-		}
-		this.listenTo( this.controller, 'selection:toggle', this.toggleDisabled );
-	},
-
-	filterChange: function( model ) {
-		if ( 'trash' === model.get( 'status' ) ) {
-			this.model.set( 'text', l10n.untrashSelected );
-		} else if ( wp.media.view.settings.mediaTrash ) {
-			this.model.set( 'text', l10n.trashSelected );
-		} else {
-			this.model.set( 'text', l10n.deleteSelected );
-		}
-	},
-
-	toggleDisabled: function() {
-		this.model.set( 'disabled', ! this.controller.state().get( 'selection' ).length );
-	},
-
-	render: function() {
-		Button.prototype.render.apply( this, arguments );
-		if ( this.controller.isModeActive( 'select' ) ) {
-			this.$el.addClass( 'delete-selected-button' );
-		} else {
-			this.$el.addClass( 'delete-selected-button hidden' );
-		}
-		this.toggleDisabled();
-		return this;
-	}
-});
-
-module.exports = DeleteSelected;
-
-},{}],7:[function(require,module,exports){
-/*globals wp */
-
-/**
- * wp.media.view.SelectModeToggleButton
- *
- * @class
- * @augments wp.media.view.Button
- * @augments wp.media.View
- * @augments wp.Backbone.View
- * @augments Backbone.View
- */
-var Button = wp.media.view.Button,
-	l10n = wp.media.view.l10n,
-	SelectModeToggle;
-
-SelectModeToggle = Button.extend({
-	initialize: function() {
-		Button.prototype.initialize.apply( this, arguments );
-		this.listenTo( this.controller, 'select:activate select:deactivate', this.toggleBulkEditHandler );
-		this.listenTo( this.controller, 'selection:action:done', this.back );
-	},
-
-	back: function () {
-		this.controller.deactivateMode( 'select' ).activateMode( 'edit' );
-	},
-
-	click: function() {
-		Button.prototype.click.apply( this, arguments );
-		if ( this.controller.isModeActive( 'select' ) ) {
-			this.back();
-		} else {
-			this.controller.deactivateMode( 'edit' ).activateMode( 'select' );
-		}
-	},
-
-	render: function() {
-		Button.prototype.render.apply( this, arguments );
-		this.$el.addClass( 'select-mode-toggle-button' );
-		return this;
-	},
-
-	toggleBulkEditHandler: function() {
-		var toolbar = this.controller.content.get().toolbar, children;
-
-		children = toolbar.$( '.media-toolbar-secondary > *, .media-toolbar-primary > *' );
-
-		// TODO: the Frame should be doing all of this.
-		if ( this.controller.isModeActive( 'select' ) ) {
-			this.model.set( 'text', l10n.cancelSelection );
-			children.not( '.media-button' ).hide();
-			this.$el.show();
-			toolbar.$( '.delete-selected-button' ).removeClass( 'hidden' );
-		} else {
-			this.model.set( 'text', l10n.bulkSelect );
-			this.controller.content.get().$el.removeClass( 'fixed' );
-			toolbar.$el.css( 'width', '' );
-			toolbar.$( '.delete-selected-button' ).addClass( 'hidden' );
-			children.not( '.spinner, .media-button' ).show();
-			this.controller.state().get( 'selection' ).reset();
-		}
-	}
-});
-
-module.exports = SelectModeToggle;
-
-},{}],8:[function(require,module,exports){
-/*globals wp, _ */
-
-/**
- * wp.media.view.EditImage.Details
- *
- * @class
- * @augments wp.media.view.EditImage
- * @augments wp.media.View
- * @augments wp.Backbone.View
- * @augments Backbone.View
- */
-var View = wp.media.View,
-	EditImage = wp.media.view.EditImage,
-	Details;
-
-Details = EditImage.extend({
-	initialize: function( options ) {
-		this.editor = window.imageEdit;
-		this.frame = options.frame;
-		this.controller = options.controller;
-		View.prototype.initialize.apply( this, arguments );
-	},
-
-	back: function() {
-		this.frame.content.mode( 'edit-metadata' );
-	},
-
-	save: function() {
-		this.model.fetch().done( _.bind( function() {
-			this.frame.content.mode( 'edit-metadata' );
-		}, this ) );
-	}
-});
-
-module.exports = Details;
-
-},{}],9:[function(require,module,exports){
-/*globals wp, _, jQuery */
-
-/**
- * wp.media.view.MediaFrame.EditAttachments
- *
- * A frame for editing the details of a specific media item.
- *
- * Opens in a modal by default.
- *
- * Requires an attachment model to be passed in the options hash under `model`.
- *
- * @class
- * @augments wp.media.view.Frame
- * @augments wp.media.View
- * @augments wp.Backbone.View
- * @augments Backbone.View
- * @mixes wp.media.controller.StateMachine
- */
-var Frame = wp.media.view.Frame,
-	MediaFrame = wp.media.view.MediaFrame,
-
-	$ = jQuery,
-	EditAttachments;
-
-EditAttachments = MediaFrame.extend({
-
-	className: 'edit-attachment-frame',
-	template:  wp.template( 'edit-attachment-frame' ),
-	regions:   [ 'title', 'content' ],
-
-	events: {
-		'click .left':  'previousMediaItem',
-		'click .right': 'nextMediaItem'
-	},
-
-	initialize: function() {
-		Frame.prototype.initialize.apply( this, arguments );
-
-		_.defaults( this.options, {
-			modal: true,
-			state: 'edit-attachment'
-		});
-
-		this.controller = this.options.controller;
-		this.gridRouter = this.controller.gridRouter;
-		this.library = this.options.library;
-
-		if ( this.options.model ) {
-			this.model = this.options.model;
-		}
-
-		this.bindHandlers();
-		this.createStates();
-		this.createModal();
-
-		this.title.mode( 'default' );
-		this.toggleNav();
-	},
-
-	bindHandlers: function() {
-		// Bind default title creation.
-		this.on( 'title:create:default', this.createTitle, this );
-
-		// Close the modal if the attachment is deleted.
-		this.listenTo( this.model, 'change:status destroy', this.close, this );
-
-		this.on( 'content:create:edit-metadata', this.editMetadataMode, this );
-		this.on( 'content:create:edit-image', this.editImageMode, this );
-		this.on( 'content:render:edit-image', this.editImageModeRender, this );
-		this.on( 'close', this.detach );
-	},
-
-	createModal: function() {
-		// Initialize modal container view.
-		if ( this.options.modal ) {
-			this.modal = new wp.media.view.Modal({
-				controller: this,
-				title:      this.options.title
-			});
-
-			this.modal.on( 'open', _.bind( function () {
-				$( 'body' ).on( 'keydown.media-modal', _.bind( this.keyEvent, this ) );
-			}, this ) );
-
-			// Completely destroy the modal DOM element when closing it.
-			this.modal.on( 'close', _.bind( function() {
-				this.modal.remove();
-				$( 'body' ).off( 'keydown.media-modal' ); /* remove the keydown event */
-				// Restore the original focus item if possible
-				$( 'li.attachment[data-id="' + this.model.get( 'id' ) +'"]' ).focus();
-				this.resetRoute();
-			}, this ) );
-
-			// Set this frame as the modal's content.
-			this.modal.content( this );
-			this.modal.open();
-		}
-	},
-
-	/**
-	 * Add the default states to the frame.
-	 */
-	createStates: function() {
-		this.states.add([
-			new wp.media.controller.EditAttachmentMetadata( { model: this.model } )
-		]);
-	},
-
-	/**
-	 * Content region rendering callback for the `edit-metadata` mode.
-	 *
-	 * @param {Object} contentRegion Basic object with a `view` property, which
-	 *                               should be set with the proper region view.
-	 */
-	editMetadataMode: function( contentRegion ) {
-		contentRegion.view = new wp.media.view.Attachment.Details.TwoColumn({
-			controller: this,
-			model:      this.model
-		});
-
-		/**
-		 * Attach a subview to display fields added via the
-		 * `attachment_fields_to_edit` filter.
-		 */
-		contentRegion.view.views.set( '.attachment-compat', new wp.media.view.AttachmentCompat({
-			controller: this,
-			model:      this.model
-		}) );
-
-		// Update browser url when navigating media details
-		if ( this.model ) {
-			this.gridRouter.navigate( this.gridRouter.baseUrl( '?item=' + this.model.id ) );
-		}
-	},
-
-	/**
-	 * Render the EditImage view into the frame's content region.
-	 *
-	 * @param {Object} contentRegion Basic object with a `view` property, which
-	 *                               should be set with the proper region view.
-	 */
-	editImageMode: function( contentRegion ) {
-		var editImageController = new wp.media.controller.EditImage( {
-			model: this.model,
-			frame: this
-		} );
-		// Noop some methods.
-		editImageController._toolbar = function() {};
-		editImageController._router = function() {};
-		editImageController._menu = function() {};
-
-		contentRegion.view = new wp.media.view.EditImage.Details( {
-			model: this.model,
-			frame: this,
-			controller: editImageController
-		} );
-	},
-
-	editImageModeRender: function( view ) {
-		view.on( 'ready', view.loadEditor );
-	},
-
-	toggleNav: function() {
-		this.$('.left').toggleClass( 'disabled', ! this.hasPrevious() );
-		this.$('.right').toggleClass( 'disabled', ! this.hasNext() );
-	},
-
-	/**
-	 * Rerender the view.
-	 */
-	rerender: function() {
-		// Only rerender the `content` region.
-		if ( this.content.mode() !== 'edit-metadata' ) {
-			this.content.mode( 'edit-metadata' );
-		} else {
-			this.content.render();
-		}
-
-		this.toggleNav();
-	},
-
-	/**
-	 * Click handler to switch to the previous media item.
-	 */
-	previousMediaItem: function() {
-		if ( ! this.hasPrevious() ) {
-			this.$( '.left' ).blur();
-			return;
-		}
-		this.model = this.library.at( this.getCurrentIndex() - 1 );
-		this.rerender();
-		this.$( '.left' ).focus();
-	},
-
-	/**
-	 * Click handler to switch to the next media item.
-	 */
-	nextMediaItem: function() {
-		if ( ! this.hasNext() ) {
-			this.$( '.right' ).blur();
-			return;
-		}
-		this.model = this.library.at( this.getCurrentIndex() + 1 );
-		this.rerender();
-		this.$( '.right' ).focus();
-	},
-
-	getCurrentIndex: function() {
-		return this.library.indexOf( this.model );
-	},
-
-	hasNext: function() {
-		return ( this.getCurrentIndex() + 1 ) < this.library.length;
-	},
-
-	hasPrevious: function() {
-		return ( this.getCurrentIndex() - 1 ) > -1;
-	},
-	/**
-	 * Respond to the keyboard events: right arrow, left arrow, except when
-	 * focus is in a textarea or input field.
-	 */
-	keyEvent: function( event ) {
-		if ( ( 'INPUT' === event.target.nodeName || 'TEXTAREA' === event.target.nodeName ) && ! ( event.target.readOnly || event.target.disabled ) ) {
-			return;
-		}
-
-		// The right arrow key
-		if ( 39 === event.keyCode ) {
-			this.nextMediaItem();
-		}
-		// The left arrow key
-		if ( 37 === event.keyCode ) {
-			this.previousMediaItem();
-		}
-	},
-
-	resetRoute: function() {
-		this.gridRouter.navigate( this.gridRouter.baseUrl( '' ) );
-	}
-});
-
-module.exports = EditAttachments;
-
-},{}],10:[function(require,module,exports){
 /*globals wp, _, Backbone */
 
 /**
@@ -860,4 +399,581 @@ Manage = MediaFrame.extend({
 
 module.exports = Manage;
 
-},{}]},{},[2]);
+
+/***/ }),
+/* 13 */
+/***/ (function(module, exports) {
+
+/*globals wp */
+
+/**
+ * wp.media.view.Attachment.Details.TwoColumn
+ *
+ * A similar view to media.view.Attachment.Details
+ * for use in the Edit Attachment modal.
+ *
+ * @class
+ * @augments wp.media.view.Attachment.Details
+ * @augments wp.media.view.Attachment
+ * @augments wp.media.View
+ * @augments wp.Backbone.View
+ * @augments Backbone.View
+ */
+var Details = wp.media.view.Attachment.Details,
+	TwoColumn;
+
+TwoColumn = Details.extend({
+	template: wp.template( 'attachment-details-two-column' ),
+
+	editAttachment: function( event ) {
+		event.preventDefault();
+		this.controller.content.mode( 'edit-image' );
+	},
+
+	/**
+	 * Noop this from parent class, doesn't apply here.
+	 */
+	toggleSelectionHandler: function() {},
+
+	render: function() {
+		Details.prototype.render.apply( this, arguments );
+
+		wp.media.mixin.removeAllPlayers();
+		this.$( 'audio, video' ).each( function (i, elem) {
+			var el = wp.media.view.MediaDetails.prepareSrc( elem );
+			new window.MediaElementPlayer( el, wp.media.mixin.mejsSettings );
+		} );
+	}
+});
+
+module.exports = TwoColumn;
+
+
+/***/ }),
+/* 14 */
+/***/ (function(module, exports) {
+
+/*globals wp, Backbone */
+
+/**
+ * wp.media.view.MediaFrame.Manage.Router
+ *
+ * A router for handling the browser history and application state.
+ *
+ * @class
+ * @augments Backbone.Router
+ */
+var Router = Backbone.Router.extend({
+	routes: {
+		'upload.php?item=:slug':    'showItem',
+		'upload.php?search=:query': 'search'
+	},
+
+	// Map routes against the page URL
+	baseUrl: function( url ) {
+		return 'upload.php' + url;
+	},
+
+	// Respond to the search route by filling the search field and trigggering the input event
+	search: function( query ) {
+		jQuery( '#media-search-input' ).val( query ).trigger( 'input' );
+	},
+
+	// Show the modal with a specific item
+	showItem: function( query ) {
+		var media = wp.media,
+			library = media.frame.state().get('library'),
+			item;
+
+		// Trigger the media frame to open the correct item
+		item = library.findWhere( { id: parseInt( query, 10 ) } );
+		if ( item ) {
+			media.frame.trigger( 'edit:attachment', item );
+		} else {
+			item = media.attachment( query );
+			media.frame.listenTo( item, 'change', function( model ) {
+				media.frame.stopListening( item );
+				media.frame.trigger( 'edit:attachment', model );
+			} );
+			item.fetch();
+		}
+	}
+});
+
+module.exports = Router;
+
+
+/***/ }),
+/* 15 */
+/***/ (function(module, exports) {
+
+/*globals wp, _ */
+
+/**
+ * wp.media.view.EditImage.Details
+ *
+ * @class
+ * @augments wp.media.view.EditImage
+ * @augments wp.media.View
+ * @augments wp.Backbone.View
+ * @augments Backbone.View
+ */
+var View = wp.media.View,
+	EditImage = wp.media.view.EditImage,
+	Details;
+
+Details = EditImage.extend({
+	initialize: function( options ) {
+		this.editor = window.imageEdit;
+		this.frame = options.frame;
+		this.controller = options.controller;
+		View.prototype.initialize.apply( this, arguments );
+	},
+
+	back: function() {
+		this.frame.content.mode( 'edit-metadata' );
+	},
+
+	save: function() {
+		this.model.fetch().done( _.bind( function() {
+			this.frame.content.mode( 'edit-metadata' );
+		}, this ) );
+	}
+});
+
+module.exports = Details;
+
+
+/***/ }),
+/* 16 */
+/***/ (function(module, exports) {
+
+/*globals wp, _, jQuery */
+
+/**
+ * wp.media.view.MediaFrame.EditAttachments
+ *
+ * A frame for editing the details of a specific media item.
+ *
+ * Opens in a modal by default.
+ *
+ * Requires an attachment model to be passed in the options hash under `model`.
+ *
+ * @class
+ * @augments wp.media.view.Frame
+ * @augments wp.media.View
+ * @augments wp.Backbone.View
+ * @augments Backbone.View
+ * @mixes wp.media.controller.StateMachine
+ */
+var Frame = wp.media.view.Frame,
+	MediaFrame = wp.media.view.MediaFrame,
+
+	$ = jQuery,
+	EditAttachments;
+
+EditAttachments = MediaFrame.extend({
+
+	className: 'edit-attachment-frame',
+	template:  wp.template( 'edit-attachment-frame' ),
+	regions:   [ 'title', 'content' ],
+
+	events: {
+		'click .left':  'previousMediaItem',
+		'click .right': 'nextMediaItem'
+	},
+
+	initialize: function() {
+		Frame.prototype.initialize.apply( this, arguments );
+
+		_.defaults( this.options, {
+			modal: true,
+			state: 'edit-attachment'
+		});
+
+		this.controller = this.options.controller;
+		this.gridRouter = this.controller.gridRouter;
+		this.library = this.options.library;
+
+		if ( this.options.model ) {
+			this.model = this.options.model;
+		}
+
+		this.bindHandlers();
+		this.createStates();
+		this.createModal();
+
+		this.title.mode( 'default' );
+		this.toggleNav();
+	},
+
+	bindHandlers: function() {
+		// Bind default title creation.
+		this.on( 'title:create:default', this.createTitle, this );
+
+		// Close the modal if the attachment is deleted.
+		this.listenTo( this.model, 'change:status destroy', this.close, this );
+
+		this.on( 'content:create:edit-metadata', this.editMetadataMode, this );
+		this.on( 'content:create:edit-image', this.editImageMode, this );
+		this.on( 'content:render:edit-image', this.editImageModeRender, this );
+		this.on( 'close', this.detach );
+	},
+
+	createModal: function() {
+		// Initialize modal container view.
+		if ( this.options.modal ) {
+			this.modal = new wp.media.view.Modal({
+				controller: this,
+				title:      this.options.title
+			});
+
+			this.modal.on( 'open', _.bind( function () {
+				$( 'body' ).on( 'keydown.media-modal', _.bind( this.keyEvent, this ) );
+			}, this ) );
+
+			// Completely destroy the modal DOM element when closing it.
+			this.modal.on( 'close', _.bind( function() {
+				this.modal.remove();
+				$( 'body' ).off( 'keydown.media-modal' ); /* remove the keydown event */
+				// Restore the original focus item if possible
+				$( 'li.attachment[data-id="' + this.model.get( 'id' ) +'"]' ).focus();
+				this.resetRoute();
+			}, this ) );
+
+			// Set this frame as the modal's content.
+			this.modal.content( this );
+			this.modal.open();
+		}
+	},
+
+	/**
+	 * Add the default states to the frame.
+	 */
+	createStates: function() {
+		this.states.add([
+			new wp.media.controller.EditAttachmentMetadata( { model: this.model } )
+		]);
+	},
+
+	/**
+	 * Content region rendering callback for the `edit-metadata` mode.
+	 *
+	 * @param {Object} contentRegion Basic object with a `view` property, which
+	 *                               should be set with the proper region view.
+	 */
+	editMetadataMode: function( contentRegion ) {
+		contentRegion.view = new wp.media.view.Attachment.Details.TwoColumn({
+			controller: this,
+			model:      this.model
+		});
+
+		/**
+		 * Attach a subview to display fields added via the
+		 * `attachment_fields_to_edit` filter.
+		 */
+		contentRegion.view.views.set( '.attachment-compat', new wp.media.view.AttachmentCompat({
+			controller: this,
+			model:      this.model
+		}) );
+
+		// Update browser url when navigating media details
+		if ( this.model ) {
+			this.gridRouter.navigate( this.gridRouter.baseUrl( '?item=' + this.model.id ) );
+		}
+	},
+
+	/**
+	 * Render the EditImage view into the frame's content region.
+	 *
+	 * @param {Object} contentRegion Basic object with a `view` property, which
+	 *                               should be set with the proper region view.
+	 */
+	editImageMode: function( contentRegion ) {
+		var editImageController = new wp.media.controller.EditImage( {
+			model: this.model,
+			frame: this
+		} );
+		// Noop some methods.
+		editImageController._toolbar = function() {};
+		editImageController._router = function() {};
+		editImageController._menu = function() {};
+
+		contentRegion.view = new wp.media.view.EditImage.Details( {
+			model: this.model,
+			frame: this,
+			controller: editImageController
+		} );
+	},
+
+	editImageModeRender: function( view ) {
+		view.on( 'ready', view.loadEditor );
+	},
+
+	toggleNav: function() {
+		this.$('.left').toggleClass( 'disabled', ! this.hasPrevious() );
+		this.$('.right').toggleClass( 'disabled', ! this.hasNext() );
+	},
+
+	/**
+	 * Rerender the view.
+	 */
+	rerender: function() {
+		// Only rerender the `content` region.
+		if ( this.content.mode() !== 'edit-metadata' ) {
+			this.content.mode( 'edit-metadata' );
+		} else {
+			this.content.render();
+		}
+
+		this.toggleNav();
+	},
+
+	/**
+	 * Click handler to switch to the previous media item.
+	 */
+	previousMediaItem: function() {
+		if ( ! this.hasPrevious() ) {
+			this.$( '.left' ).blur();
+			return;
+		}
+		this.model = this.library.at( this.getCurrentIndex() - 1 );
+		this.rerender();
+		this.$( '.left' ).focus();
+	},
+
+	/**
+	 * Click handler to switch to the next media item.
+	 */
+	nextMediaItem: function() {
+		if ( ! this.hasNext() ) {
+			this.$( '.right' ).blur();
+			return;
+		}
+		this.model = this.library.at( this.getCurrentIndex() + 1 );
+		this.rerender();
+		this.$( '.right' ).focus();
+	},
+
+	getCurrentIndex: function() {
+		return this.library.indexOf( this.model );
+	},
+
+	hasNext: function() {
+		return ( this.getCurrentIndex() + 1 ) < this.library.length;
+	},
+
+	hasPrevious: function() {
+		return ( this.getCurrentIndex() - 1 ) > -1;
+	},
+	/**
+	 * Respond to the keyboard events: right arrow, left arrow, except when
+	 * focus is in a textarea or input field.
+	 */
+	keyEvent: function( event ) {
+		if ( ( 'INPUT' === event.target.nodeName || 'TEXTAREA' === event.target.nodeName ) && ! ( event.target.readOnly || event.target.disabled ) ) {
+			return;
+		}
+
+		// The right arrow key
+		if ( 39 === event.keyCode ) {
+			this.nextMediaItem();
+		}
+		// The left arrow key
+		if ( 37 === event.keyCode ) {
+			this.previousMediaItem();
+		}
+	},
+
+	resetRoute: function() {
+		this.gridRouter.navigate( this.gridRouter.baseUrl( '' ) );
+	}
+});
+
+module.exports = EditAttachments;
+
+
+/***/ }),
+/* 17 */
+/***/ (function(module, exports) {
+
+/*globals wp */
+
+/**
+ * wp.media.view.SelectModeToggleButton
+ *
+ * @class
+ * @augments wp.media.view.Button
+ * @augments wp.media.View
+ * @augments wp.Backbone.View
+ * @augments Backbone.View
+ */
+var Button = wp.media.view.Button,
+	l10n = wp.media.view.l10n,
+	SelectModeToggle;
+
+SelectModeToggle = Button.extend({
+	initialize: function() {
+		Button.prototype.initialize.apply( this, arguments );
+		this.listenTo( this.controller, 'select:activate select:deactivate', this.toggleBulkEditHandler );
+		this.listenTo( this.controller, 'selection:action:done', this.back );
+	},
+
+	back: function () {
+		this.controller.deactivateMode( 'select' ).activateMode( 'edit' );
+	},
+
+	click: function() {
+		Button.prototype.click.apply( this, arguments );
+		if ( this.controller.isModeActive( 'select' ) ) {
+			this.back();
+		} else {
+			this.controller.deactivateMode( 'edit' ).activateMode( 'select' );
+		}
+	},
+
+	render: function() {
+		Button.prototype.render.apply( this, arguments );
+		this.$el.addClass( 'select-mode-toggle-button' );
+		return this;
+	},
+
+	toggleBulkEditHandler: function() {
+		var toolbar = this.controller.content.get().toolbar, children;
+
+		children = toolbar.$( '.media-toolbar-secondary > *, .media-toolbar-primary > *' );
+
+		// TODO: the Frame should be doing all of this.
+		if ( this.controller.isModeActive( 'select' ) ) {
+			this.model.set( 'text', l10n.cancelSelection );
+			children.not( '.media-button' ).hide();
+			this.$el.show();
+			toolbar.$( '.delete-selected-button' ).removeClass( 'hidden' );
+		} else {
+			this.model.set( 'text', l10n.bulkSelect );
+			this.controller.content.get().$el.removeClass( 'fixed' );
+			toolbar.$el.css( 'width', '' );
+			toolbar.$( '.delete-selected-button' ).addClass( 'hidden' );
+			children.not( '.spinner, .media-button' ).show();
+			this.controller.state().get( 'selection' ).reset();
+		}
+	}
+});
+
+module.exports = SelectModeToggle;
+
+
+/***/ }),
+/* 18 */
+/***/ (function(module, exports) {
+
+/*globals wp */
+
+/**
+ * wp.media.view.DeleteSelectedButton
+ *
+ * A button that handles bulk Delete/Trash logic
+ *
+ * @class
+ * @augments wp.media.view.Button
+ * @augments wp.media.View
+ * @augments wp.Backbone.View
+ * @augments Backbone.View
+ */
+var Button = wp.media.view.Button,
+	l10n = wp.media.view.l10n,
+	DeleteSelected;
+
+DeleteSelected = Button.extend({
+	initialize: function() {
+		Button.prototype.initialize.apply( this, arguments );
+		if ( this.options.filters ) {
+			this.listenTo( this.options.filters.model, 'change', this.filterChange );
+		}
+		this.listenTo( this.controller, 'selection:toggle', this.toggleDisabled );
+	},
+
+	filterChange: function( model ) {
+		if ( 'trash' === model.get( 'status' ) ) {
+			this.model.set( 'text', l10n.untrashSelected );
+		} else if ( wp.media.view.settings.mediaTrash ) {
+			this.model.set( 'text', l10n.trashSelected );
+		} else {
+			this.model.set( 'text', l10n.deleteSelected );
+		}
+	},
+
+	toggleDisabled: function() {
+		this.model.set( 'disabled', ! this.controller.state().get( 'selection' ).length );
+	},
+
+	render: function() {
+		Button.prototype.render.apply( this, arguments );
+		if ( this.controller.isModeActive( 'select' ) ) {
+			this.$el.addClass( 'delete-selected-button' );
+		} else {
+			this.$el.addClass( 'delete-selected-button hidden' );
+		}
+		this.toggleDisabled();
+		return this;
+	}
+});
+
+module.exports = DeleteSelected;
+
+
+/***/ }),
+/* 19 */
+/***/ (function(module, exports) {
+
+/*globals wp */
+
+/**
+ * wp.media.view.DeleteSelectedPermanentlyButton
+ *
+ * When MEDIA_TRASH is true, a button that handles bulk Delete Permanently logic
+ *
+ * @class
+ * @augments wp.media.view.DeleteSelectedButton
+ * @augments wp.media.view.Button
+ * @augments wp.media.View
+ * @augments wp.Backbone.View
+ * @augments Backbone.View
+ */
+var Button = wp.media.view.Button,
+	DeleteSelected = wp.media.view.DeleteSelectedButton,
+	DeleteSelectedPermanently;
+
+DeleteSelectedPermanently = DeleteSelected.extend({
+	initialize: function() {
+		DeleteSelected.prototype.initialize.apply( this, arguments );
+		this.listenTo( this.controller, 'select:activate', this.selectActivate );
+		this.listenTo( this.controller, 'select:deactivate', this.selectDeactivate );
+	},
+
+	filterChange: function( model ) {
+		this.canShow = ( 'trash' === model.get( 'status' ) );
+	},
+
+	selectActivate: function() {
+		this.toggleDisabled();
+		this.$el.toggleClass( 'hidden', ! this.canShow );
+	},
+
+	selectDeactivate: function() {
+		this.toggleDisabled();
+		this.$el.addClass( 'hidden' );
+	},
+
+	render: function() {
+		Button.prototype.render.apply( this, arguments );
+		this.selectActivate();
+		return this;
+	}
+});
+
+module.exports = DeleteSelectedPermanently;
+
+
+/***/ })
+/******/ ]);
\ No newline at end of file
